pub enum ScheduleError {
BadEntry {
raw: String,
},
BadTick {
raw: String,
source: ParseIntError,
},
NoActions {
model: String,
},
UnknownAction {
id: String,
model: String,
known: Vec<&'static str>,
},
}Expand description
An --act entry that cannot be resolved.
Variants
BadEntry
An entry not of the form ID@TICK.
BadTick
An entry whose tick is not a whole number.
NoActions
An entry for a model that declares no actions.
UnknownAction
An action id that model does not declare.