StepCtx

Struct StepCtx 

pub struct StepCtx<'a, A: AgentModel + ?Sized> {
    pub field: <A::Field as FieldLayer>::Read<'a>,
    pub index: &'a A::Index,
    pub params: &'a A::Params,
    pub extent: Extent,
}
Context an agent kernel reads besides its own lanes.

Fields

field: <A::Field as FieldLayer>::Read<'a>

Field layer, as an agent kernel reads it.

index: &'a A::Index

Neighbour index, rebuilt from the positions before the step.

params: &'a A::Params

Hot parameters of this tick.

extent: Extent

World size.