pub enum DesignError {
UnequalLengths {
lengths: Vec<usize>,
},
TooManyConfigs,
NoSamples,
NoFactors,
UnlistedLevels {
factor_index: usize,
},
NoLevels {
factor_index: usize,
},
}Expand description
A block whose design cannot combine its factors.
Variants
UnequalLengths
A zip over factors with different numbers of levels.
TooManyConfigs
A design whose configs would take the plan past MAX_CONFIGS.
NoSamples
A random or Latin hypercube design of 0 samples.
NoFactors
A random or Latin hypercube design with no factor to draw.
UnlistedLevels
Factor factor_index of a factorial or zip design, a range with no listed levels.
NoLevels
Factor factor_index, a list with no levels.