pub enum LevelSpecError {
NotANumber {
part: String,
range: String,
source: ParseFloatError,
},
BadRange {
range: String,
},
}Expand description
Text that cannot be parsed as a LevelSpec.
Variants
NotANumber
A part of range range that is not a number.
Fields

source: ParseFloatErrorReason the part cannot be parsed as an f64.
BadRange
A range with other than two or three parts.