pub enum SearchSpecError {
NoEvaluations,
NoBatch,
BatchTooLarge {
batch_size: usize,
},
MissingObjective {
algorithm: &'static str,
},
UnusedObjective,
Setting {
key: &'static str,
value: String,
expected: String,
},
}Expand description
A search spec that cannot run.
Variants
NoEvaluations
A budget of 0 evaluations.
NoBatch
A batch size of 0.
BatchTooLarge
A batch size past MAX_CONFIGS.
MissingObjective
A random search, hill climb or genetic algorithm with no objective.
UnusedObjective
An objective given to a Pattern Space Exploration. Pattern Space Exploration uses no objective.
Setting
Setting key set to value, where it accepts expected.