pub struct ConfigKey(/* private fields */);Expand description
Key of the config a genome decodes to, one entry per factor.
Two genomes of one space have equal keys exactly when they decode to the same config.