pub struct ReplicateSummary {
pub n: u64,
pub mean: Option<f64>,
pub standard_deviation: Option<f64>,
pub ci95: Option<(f64, f64)>,
}Expand description
Statistics of one output over the replicates of a config.
Fields
n: u64Number of finite values.
mean: Option<f64>Mean of the finite values, None when there are no finite values.
standard_deviation: Option<f64>Sample standard deviation, None below two values.
ci95: Option<(f64, f64)>Low and high ends of the 95% confidence interval for the mean, None below two values.