pub enum ReducerKind {
Final,
Min,
Max,
Mean,
ArgMax,
ArgMin,
FirstCrossing(Comparison),
WindowMean {
start: u64,
end: u64,
},
}Expand description
Fold a reducer applies to its column’s samples.
Variants
Final
Last finite sampled value.
Min
Least finite sampled value.
Max
Greatest finite sampled value.
Mean
Mean of the finite sampled values.
ArgMax
First sampled tick of the greatest value.
ArgMin
First sampled tick of the least value.
FirstCrossing(Comparison)
First sampled tick whose value passes the comparison, empty when no sample passes.
WindowMean
Mean of the samples from tick start to tick end inclusive.
Implementations